.color {
  me: rgb(123, 123, 123);
  impressed: #FfEedD;
  again: #ABCDEF;
  andagain:#aa66cc;
  background-color:#aa66ccc;
  filter: chroma(color="#FFFFFF");
  background: none repeat scroll 0 0 rgb(255, 0,0);
  alpha: rgba(1, 2, 3, 4);
  color:#1122aa
}

#AABBCC {
  background-color:#ffee11;
  filter: chroma(color = #FFFFFF );
  color:#441122;
  foo:#00fF11 #ABC #AABbCc #123344;
  border-color:#aa66ccC
}

.foo #AABBCC {
  background-color:#fFEe11;
  color:#441122;
  border-color:#AbC;
  filter: chroma(color= #FFFFFF)
}

.bar, #AABBCC {
  background-color:#FFee11;
  border-color:#00fF11 #ABCDEF;
  filter: chroma(color=#11FFFFFF);
  color:#441122;
}

.foo, #AABBCC.foobar {
  background-color:#ffee11;
  border-color:#00fF11 #ABCDEF #AABbCc;
  color:#441122;
}

@media screen {
    .bar, #AABBCC {
      background-color:#ffEE11;
      color:#441122
    }
}
