/*	this file contains no css, it exists purely to put the revision number into the 
	combined css before uploading it to SiteManager. The exclaimation at the start
	of the comment informs yuicompressor not to strip the comment out */
 
/*! $LastChangedRevision: 81 $ $LastChangedDate: 2009-05-27 17:41:02 +0100 (Wed, 27 May 2009) $ */
 
body {
    yo: cats;
}
ul[id$=foo] label:hover {yo: yo;}