a { 
  margin: 0px 0pt 0em 0%;
  _padding-top: 0ex;
  background-position: 0 0;
  padding: 0in 0cm 0mm 0pc;
  transition: opacity .0s;
  transition-delay: 0.0ms;
  transform: rotate3d(0grad, 0rad, 0deg);
  pitch: 0khz;
  pitch:
0hz /* intentionally on next line */;
}
