@media screen and/*!YUI-Compresser */(-webkit-min-device-pixel-ratio:0) {
  a{
    b: 1;
  }
}


@media screen and/*! */ /*! */(-webkit-min-device-pixel-ratio:0) {
  a{
    b: 1;
  }
}


@media -webkit-min-device-pixel-ratio:0 {
  a{
    b: 1;
  }
}